'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var nodeUtils = require('@component-controls/core/node-utils');
var webpackBuild = require('@component-controls/base-integration/webpack-build');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);

const HtmlWebpackPlugin = require('safe-require')('html-webpack-plugin');
class HTMLInjectStylePlugin {
    constructor(options) {
        this.options = options;
    }
    apply(compiler) {
        if (this.options.styles) {
            compiler.hooks.compilation.tap(HTMLInjectStylePlugin.pluginName, compilation => {
                if (HtmlWebpackPlugin && HtmlWebpackPlugin.getHooks) {
                    const hooks = HtmlWebpackPlugin.getHooks(compilation);
                    hooks.alterAssetTagGroups.tapAsync(HTMLInjectStylePlugin.pluginName, (data, cb) => {
                        console.log('APPLY tapAsync');
                        data.headTags.push({
                            tagName: 'style',
                            innerHTML: this.options.styles,
                        });
                        cb(null, data);
                    });
                }
                else {
                    throw new Error('Cannot find HtmlWebpackPlugin hooks to inject css styles');
                }
            });
        }
    }
}
HTMLInjectStylePlugin.pluginName = 'html-inject-style-webpack-plugin';

const withComponentControls = (props) => async () => {
    return webpackBuild.asyncWebpackConfig(Object.assign(Object.assign({}, props), { callback: async ({ config, options }) => {
            if (options) {
                const cssBundle = nodeUtils.getCSSFilePath(options);
                if (fs__default['default'].existsSync(cssBundle)) {
                    const styles = fs__default['default'].readFileSync(cssBundle, 'utf8');
                    config.plugins.push(new HTMLInjectStylePlugin({ styles: styles }));
                    return config;
                }
            }
            return config;
        } }));
};

exports.withComponentControls = withComponentControls;
